==> types_aiobotocore_qldb_session-2.4.0-py3-none-any.whl: types_aiobotocore_qldb_session/type_defs.py <==
"""
Type annotations for qldb-session service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qldb_session/type_defs/)

Usage::

    ```python
    from types_aiobotocore_qldb_session.type_defs import TimingInformationTypeDef

    data: TimingInformationTypeDef = {...}
    ```
"""
import sys
from typing import IO, Any, Dict, List, Mapping, Sequence, Union

from aiobotocore.response import StreamingBody

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "TimingInformationTypeDef",
    "CommitTransactionRequestTypeDef",
    "IOUsageTypeDef",
    "ValueHolderTypeDef",
    "FetchPageRequestTypeDef",
    "ResponseMetadataTypeDef",
    "StartSessionRequestTypeDef",
    "AbortTransactionResultTypeDef",
    "EndSessionResultTypeDef",
    "StartSessionResultTypeDef",
    "StartTransactionResultTypeDef",
    "CommitTransactionResultTypeDef",
    "ExecuteStatementRequestTypeDef",
    "PageTypeDef",
    "SendCommandRequestRequestTypeDef",
    "ExecuteStatementResultTypeDef",
    "FetchPageResultTypeDef",
    "SendCommandResultTypeDef",
)

TimingInformationTypeDef = TypedDict(
    "TimingInformationTypeDef",
    {
        "ProcessingTimeMilliseconds": int,
    },
    total=False,
)

CommitTransactionRequestTypeDef = TypedDict(
    "CommitTransactionRequestTypeDef",
    {
        "TransactionId": str,
        "CommitDigest": Union[str, bytes, IO[Any], StreamingBody],
    },
)

IOUsageTypeDef = TypedDict(
    "IOUsageTypeDef",
    {
        "ReadIOs": int,
        "WriteIOs": int,
    },
    total=False,
)

ValueHolderTypeDef = TypedDict(
    "ValueHolderTypeDef",
    {
        "IonBinary": Union[str, bytes, IO[Any], StreamingBody],
        "IonText": str,
    },
    total=False,
)

FetchPageRequestTypeDef = TypedDict(
    "FetchPageRequestTypeDef",
    {
        "TransactionId": str,
        "NextPageToken": str,
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

StartSessionRequestTypeDef = TypedDict(
    "StartSessionRequestTypeDef",
    {
        "LedgerName": str,
    },
)

AbortTransactionResultTypeDef = TypedDict(
    "AbortTransactionResultTypeDef",
    {
        "TimingInformation": TimingInformationTypeDef,
    },
    total=False,
)

EndSessionResultTypeDef = TypedDict(
    "EndSessionResultTypeDef",
    {
        "TimingInformation": TimingInformationTypeDef,
    },
    total=False,
)

StartSessionResultTypeDef = TypedDict(
    "StartSessionResultTypeDef",
    {
        "SessionToken": str,
        "TimingInformation": TimingInformationTypeDef,
    },
    total=False,
)

StartTransactionResultTypeDef = TypedDict(
    "StartTransactionResultTypeDef",
    {
        "TransactionId": str,
        "TimingInformation": TimingInformationTypeDef,
    },
    total=False,
)

CommitTransactionResultTypeDef = TypedDict(
    "CommitTransactionResultTypeDef",
    {
        "TransactionId": str,
        "CommitDigest": bytes,
        "TimingInformation": TimingInformationTypeDef,
        "ConsumedIOs": IOUsageTypeDef,
    },
    total=False,
)

_RequiredExecuteStatementRequestTypeDef = TypedDict(
    "_RequiredExecuteStatementRequestTypeDef",
    {
        "TransactionId": str,
        "Statement": str,
    },
)
_OptionalExecuteStatementRequestTypeDef = TypedDict(
    "_OptionalExecuteStatementRequestTypeDef",
    {
        "Parameters": Sequence[ValueHolderTypeDef],
    },
    total=False,
)


class ExecuteStatementRequestTypeDef(
    _RequiredExecuteStatementRequestTypeDef, _OptionalExecuteStatementRequestTypeDef
):
    pass


PageTypeDef = TypedDict(
    "PageTypeDef",
    {
        "Values": List[ValueHolderTypeDef],
        "NextPageToken": str,
    },
    total=False,
)

SendCommandRequestRequestTypeDef = TypedDict(
    "SendCommandRequestRequestTypeDef",
    {
        "SessionToken": str,
        "StartSession": StartSessionRequestTypeDef,
        "StartTransaction": Mapping[str, Any],
        "EndSession": Mapping[str, Any],
        "CommitTransaction": CommitTransactionRequestTypeDef,
        "AbortTransaction": Mapping[str, Any],
        "ExecuteStatement": ExecuteStatementRequestTypeDef,
        "FetchPage": FetchPageRequestTypeDef,
    },
    total=False,
)

ExecuteStatementResultTypeDef = TypedDict(
    "ExecuteStatementResultTypeDef",
    {
        "FirstPage": PageTypeDef,
        "TimingInformation": TimingInformationTypeDef,
        "ConsumedIOs": IOUsageTypeDef,
    },
    total=False,
)

FetchPageResultTypeDef = TypedDict(
    "FetchPageResultTypeDef",
    {
        "Page": PageTypeDef,
        "TimingInformation": TimingInformationTypeDef,
        "ConsumedIOs": IOUsageTypeDef,
    },
    total=False,
)

SendCommandResultTypeDef = TypedDict(
    "SendCommandResultTypeDef",
    {
        "StartSession": StartSessionResultTypeDef,
        "StartTransaction": StartTransactionResultTypeDef,
        "EndSession": EndSessionResultTypeDef,
        "CommitTransaction": CommitTransactionResultTypeDef,
        "AbortTransaction": AbortTransactionResultTypeDef,
        "ExecuteStatement": ExecuteStatementResultTypeDef,
        "FetchPage": FetchPageResultTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

==> types_aiobotocore_qldb_session-2.9.1-py3-none-any.whl: types_aiobotocore_qldb_session/type_defs.py <==
"""
Type annotations for qldb-session service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qldb_session/type_defs/)

Usage::

    ```python
    from types_aiobotocore_qldb_session.type_defs import TimingInformationTypeDef

    data: TimingInformationTypeDef = ...
    ```
"""

import sys
from typing import IO, Any, Dict, List, Mapping, Sequence, Union

from aiobotocore.response import StreamingBody

if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "TimingInformationTypeDef",
    "BlobTypeDef",
    "IOUsageTypeDef",
    "FetchPageRequestTypeDef",
    "ResponseMetadataTypeDef",
    "StartSessionRequestTypeDef",
    "AbortTransactionResultTypeDef",
    "EndSessionResultTypeDef",
    "StartSessionResultTypeDef",
    "StartTransactionResultTypeDef",
    "CommitTransactionRequestTypeDef",
    "ValueHolderTypeDef",
    "CommitTransactionResultTypeDef",
    "ExecuteStatementRequestTypeDef",
    "PageTypeDef",
    "SendCommandRequestRequestTypeDef",
    "ExecuteStatementResultTypeDef",
    "FetchPageResultTypeDef",
    "SendCommandResultTypeDef",
)

TimingInformationTypeDef = TypedDict(
    "TimingInformationTypeDef",
    {
        "ProcessingTimeMilliseconds": NotRequired[int],
    },
)
BlobTypeDef = Union[str, bytes, IO[Any], StreamingBody]
IOUsageTypeDef = TypedDict(
    "IOUsageTypeDef",
    {
        "ReadIOs": NotRequired[int],
        "WriteIOs": NotRequired[int],
    },
)
FetchPageRequestTypeDef = TypedDict(
    "FetchPageRequestTypeDef",
    {
        "TransactionId": str,
        "NextPageToken": str,
    },
)
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)
StartSessionRequestTypeDef = TypedDict(
    "StartSessionRequestTypeDef",
    {
        "LedgerName": str,
    },
)
AbortTransactionResultTypeDef = TypedDict(
    "AbortTransactionResultTypeDef",
    {
        "TimingInformation": NotRequired[TimingInformationTypeDef],
    },
)
EndSessionResultTypeDef = TypedDict(
    "EndSessionResultTypeDef",
    {
        "TimingInformation": NotRequired[TimingInformationTypeDef],
    },
)
StartSessionResultTypeDef = TypedDict(
    "StartSessionResultTypeDef",
    {
        "SessionToken": NotRequired[str],
        "TimingInformation": NotRequired[TimingInformationTypeDef],
    },
)
StartTransactionResultTypeDef = TypedDict(
    "StartTransactionResultTypeDef",
    {
        "TransactionId": NotRequired[str],
        "TimingInformation": NotRequired[TimingInformationTypeDef],
    },
)
CommitTransactionRequestTypeDef = TypedDict(
    "CommitTransactionRequestTypeDef",
    {
        "TransactionId": str,
        "CommitDigest": BlobTypeDef,
    },
)
ValueHolderTypeDef = TypedDict(
    "ValueHolderTypeDef",
    {
        "IonBinary": NotRequired[BlobTypeDef],
        "IonText": NotRequired[str],
    },
)
CommitTransactionResultTypeDef = TypedDict(
    "CommitTransactionResultTypeDef",
    {
        "TransactionId": NotRequired[str],
        "CommitDigest": NotRequired[bytes],
        "TimingInformation": NotRequired[TimingInformationTypeDef],
        "ConsumedIOs": NotRequired[IOUsageTypeDef],
    },
)
ExecuteStatementRequestTypeDef = TypedDict(
    "ExecuteStatementRequestTypeDef",
    {
        "TransactionId": str,
        "Statement": str,
        "Parameters": NotRequired[Sequence[ValueHolderTypeDef]],
    },
)
PageTypeDef = TypedDict(
    "PageTypeDef",
    {
        "Values": NotRequired[List[ValueHolderTypeDef]],
        "NextPageToken": NotRequired[str],
    },
)
SendCommandRequestRequestTypeDef = TypedDict(
    "SendCommandRequestRequestTypeDef",
    {
        "SessionToken": NotRequired[str],
        "StartSession": NotRequired[StartSessionRequestTypeDef],
        "StartTransaction": NotRequired[Mapping[str, Any]],
        "EndSession": NotRequired[Mapping[str, Any]],
        "CommitTransaction": NotRequired[CommitTransactionRequestTypeDef],
        "AbortTransaction": NotRequired[Mapping[str, Any]],
        "ExecuteStatement": NotRequired[ExecuteStatementRequestTypeDef],
        "FetchPage": NotRequired[FetchPageRequestTypeDef],
    },
)
ExecuteStatementResultTypeDef = TypedDict(
    "ExecuteStatementResultTypeDef",
    {
        "FirstPage": NotRequired[PageTypeDef],
        "TimingInformation": NotRequired[TimingInformationTypeDef],
        "ConsumedIOs": NotRequired[IOUsageTypeDef],
    },
)
FetchPageResultTypeDef = TypedDict(
    "FetchPageResultTypeDef",
    {
        "Page": NotRequired[PageTypeDef],
        "TimingInformation": NotRequired[TimingInformationTypeDef],
        "ConsumedIOs": NotRequired[IOUsageTypeDef],
    },
)
SendCommandResultTypeDef = TypedDict(
    "SendCommandResultTypeDef",
    {
        "StartSession": StartSessionResultTypeDef,
        "StartTransaction": StartTransactionResultTypeDef,
        "EndSession": EndSessionResultTypeDef,
        "CommitTransaction": CommitTransactionResultTypeDef,
        "AbortTransaction": AbortTransactionResultTypeDef,
        "ExecuteStatement": ExecuteStatementResultTypeDef,
        "FetchPage": FetchPageResultTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
